@@ -2,13 +2,13 @@
 #
 # mqmpermutation.R
 #
-# Copyright (c) 2009-2010, Danny Arends
+# Copyright (c) 2009-2013, Danny Arends
 #
 # Modified by Pjotr Prins and Karl Broman
 #
 # 
 # first written Februari 2009
-# last modified April 2010
+# last modified Sep 2013
 #
 #     This program is free software; you can redistribute it and/or
 #     modify it under the terms of the GNU General Public License,
@@ -124,10 +124,9 @@ mqmpermutation <- function(cross,scanfunction=scanone,pheno.col=1,multicore=TRUE
 		SUM <- 0
 		AVG <- 0
 		LEFT <- 0
-		#TEST FOR SNOW CAPABILITIES
-#		if(("snow" %in% installed.packages()[1:dim(installed.packages())[1]]) && multicore){
-		if(multicore && n.cluster >1 && suppressWarnings(require(snow,quietly=TRUE))) {
-			if(verbose) cat("INFO: Library snow found using ",n.cluster," Cores/CPU's/PC's for calculation.\n")
+		if(multicore && n.cluster >1) {
+                  updateParallelRNG(n.cluster)
+			if(verbose) cat("INFO: Using ",n.cluster," Cores/CPU's/PC's for calculation.\n")
 			for(x in 1:(batches)){
 				start <- proc.time()
 				if(verbose) {
@@ -140,10 +139,8 @@ mqmpermutation <- function(cross,scanfunction=scanone,pheno.col=1,multicore=TRUE
 				}else{
 					boots <- bootstraps[((batchsize*(x-1))+1):(batchsize*(x-1)+batchsize)]
 				}			
-				cl <- makeCluster(n.cluster)
-				clusterEvalQ(cl, require(qtl, quietly=TRUE)) 
-				res <- parLapply(cl,boots, fun=snowCoreBOOT,all.data=cross,scanfunction=scanfunction,bootmethod=bootmethod,cofactors=cofactors,verbose=verbose,...)
-				stopCluster(cl)
+				res <- mclapply(boots, snowCoreBOOT, all.data=cross, scanfunction=scanfunction, bootmethod=bootmethod,
+                                                cofactors=cofactors, verbose=verbose, mc.cores=n.cluster, ...)
 				results <- c(results,res)
 				if(plot){
 					temp <- c(res0,results)
@@ -164,7 +161,7 @@ mqmpermutation <- function(cross,scanfunction=scanone,pheno.col=1,multicore=TRUE
                                 }
 			}
 		}else{
-			if(verbose) cat("INFO: Library snow not found, so going into singlemode.\n")
+			if(verbose) cat("INFO: Going into singlemode.\n")
 			for(x in 1:(batches)){
 				start <- proc.time()
                                 if(verbose) {
